"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupDaoWorldsContractService = exports.setupDaoWorldsDeltaRepository = exports.setupDaoWorldsActionRepository = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const mappers_1 = require("./actions/data/mappers");
const data_sources_1 = require("./actions/data/data-sources");
const repositories_1 = require("./actions/domain/repositories");
const dao_worlds_contract_service_1 = require("./services/dao-worlds-contract.service");
const dao_worlds_contract_service_impl_1 = require("./services/dao-worlds-contract.service-impl");
const mappers_2 = require("./deltas/data/mappers");
const data_sources_2 = require("./deltas/data/data-sources");
const repositories_2 = require("./deltas/domain/repositories");
const setupDaoWorldsActionRepository = async (mongo, container) => {
    let mongoSource;
    if (mongo instanceof aw_storage_mongodb_1.MongoSource) {
        mongoSource = mongo;
    }
    else {
        mongoSource = await aw_storage_mongodb_1.MongoSource.create(mongo);
    }
    const mapper = new mappers_1.DaoWorldsActionMongoMapper();
    const repository = new aw_core_1.RepositoryImpl(new data_sources_1.DaoWorldsActionMongoSource(mongoSource), mapper, new aw_storage_mongodb_1.MongoQueryBuilders(mapper));
    if (container) {
        container
            .bind(repositories_1.DaoWorldsActionRepository.Token)
            .toConstantValue(repository);
    }
    return repository;
};
exports.setupDaoWorldsActionRepository = setupDaoWorldsActionRepository;
const setupDaoWorldsDeltaRepository = async (mongo, container) => {
    let mongoSource;
    if (mongo instanceof aw_storage_mongodb_1.MongoSource) {
        mongoSource = mongo;
    }
    else {
        mongoSource = await aw_storage_mongodb_1.MongoSource.create(mongo);
    }
    const mapper = new mappers_2.DaoWorldsDeltaMongoMapper();
    const repository = new aw_core_1.RepositoryImpl(new data_sources_2.DaoWorldsDeltaMongoSource(mongoSource), mapper, new aw_storage_mongodb_1.MongoQueryBuilders(mapper));
    if (container) {
        container
            .bind(repositories_2.DaoWorldsDeltaRepository.Token)
            .toConstantValue(repository);
    }
    return repository;
};
exports.setupDaoWorldsDeltaRepository = setupDaoWorldsDeltaRepository;
const setupDaoWorldsContractService = (antelopeRpcSourceImpl, serviceUrl, container) => {
    const service = new dao_worlds_contract_service_impl_1.DaoWorldsContractServiceImpl(antelopeRpcSourceImpl, serviceUrl);
    if (container) {
        container
            .bind(dao_worlds_contract_service_1.DaoWorldsContractService.Token)
            .toConstantValue(service);
    }
    return service;
};
exports.setupDaoWorldsContractService = setupDaoWorldsContractService;
